<?php

namespace App\Http\Controllers\Server;
use App\Http\Controllers\Controller;
use App\Models\User;
use App\Http\Requests\AcceptRequest;
use Illuminate\Support\Facades\Auth;

class DisconnectController extends Controller
{
    /**
     *  @OA\Post(
     *    tags={"Servers:User"},
     *    path="/user/{id}/disconnect",
     *    summary="Disconnect an user",
     *    @OA\Parameter(
     *      name="id",
     *      in="path",
     *      required=true,
     *      @OA\Schema(type="integer")
     *    ),
     *    @OA\Response(
     *      response="401",
     *      ref="#/components/responses/401"
     *    ),
     *    @OA\Response(
     *      response="404",
     *      ref="#/components/responses/404"
     *    ),
     *    @OA\Response(
     *      response="403",
     *      description="Forbidden",
     *      @OA\JsonContent(
     *        @OA\Property(
     *          property="message",
     *          type="string",
     *        ),
     *      )
     *    ),
     *    @OA\Response(
     *      response="204",
     *      description="OK"
     *    ),
     *    security={{"server-jwt":{}}},
     *  )
     */
    public function disconnect($id) {
        $server = Auth::guard('server')->user();
        $user = User::findOrFail($id);

        if (!($user->server_id === $server->id && $user->server_state !== 'offline')) {
            return response()->json([
                'message' => 'User is not connected',
            ], 403);
        }

        $user->disconnect();
        return response()->noContent();
    }
}
