<?php

namespace App\Http\Requests;

use Illuminate\Foundation\Http\FormRequest;

/**
 * @OA\RequestBody(
 *   request="CreateGame",
 *   required=true,
 *   @OA\JsonContent(
 *     required={"users","mode"},
 *     @OA\Property(
 *       property="mode",
 *       type="string",
 *       description="Mode of the game",
 *       enum={"ffa", "team"}
 *     ),
 *     @OA\Property(
 *       property="users",
 *       type="array",
 *       description="Users who participated in the game",
 *       @OA\Items(
 *         required={"id","team_id"},
 *         @OA\Property(
 *           property="id",
 *           type="int",
 *           description="ID of the user"
 *         ),
 *         @OA\Property(
 *           property="team_id",
 *           type="int",
 *           description="ID of the team of the user"
 *         )
 *       )
 *     ),
 *   ),
 * ),
 */
class CreateGameRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, mixed>
     */
    public function rules()
    {
        return [
            "users" => "required|array|min:2",
            "users.*.id" => "required|exists:users,id|distinct",
            "users.*.team_id" => "required_if:mode,team|numeric|integer",
            "mode" => "required|string|in:ffa,team"
        ];
    }
}
