<?php

namespace App\Http\Requests;

use Illuminate\Foundation\Http\FormRequest;

/**
 * @OA\RequestBody(
 *   request="ResetPassword",
 *   required=true,
 *   @OA\JsonContent(
 *     required={"token", "email", "password"},
 *     @OA\Property(
 *       property="token",
 *       type="string",
 *       description="Recovery token",
 *     ),
 *     @OA\Property(
 *       property="email",
 *       type="string",
 *       format="email",
 *       description="Email of the user",
 *     ),
 *     @OA\Property(
 *       property="password",
 *       type="string",
 *       description="New password of the user",
 *     ),
 *   ),
 * ),
 */
class ResetPasswordRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, mixed>
     */
    public function rules()
    {
        return [
            'token' => 'required',
            'email' => 'required|email',
            'password' => 'required|string|min:6',
        ];
    }
}
