<?php

namespace App\Http\Requests;

use Illuminate\Foundation\Http\FormRequest;

/**
 * @OA\RequestBody(
 *   request="UpdateGame",
 *   required=true,
 *   @OA\JsonContent(
 *     required={"state"},
 *       @OA\Property(
 *         property="state",
 *         type="string",
 *         enum={"playing", "finished"}
 *       ),
 *       @OA\Property(
 *       property="users",
 *       type="array",
 *       description="Users who participated in the game. Only needed when state == finished",
 *       @OA\Items(
 *         required={"id","winner", "rank"},
 *         @OA\Property(
 *           property="id",
 *           type="int",
 *           description="ID of the user"
 *         ),
 *         @OA\Property(
 *           property="winner",
 *           type="boolean",
 *           description="Wether the user won or not (can have multiple winners in team mode)"
 *                   ),
 *         @OA\Property(
 *           property="rank",
 *           type="int",
 *           description="Rank of the user (from 1 to 4). In team mode, the winning team is 1 and the losing team is 2"
 *         )
 *       )
 *     ),
 *   ),
 * ),
 */
class UpdateGameRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, mixed>
     */
    public function rules()
    {
        return [
            'state' => 'required|string|in:finished',
            "users" => "required_if:state,finished|array|min:2",
            "users.*.id" => "required_with:users|exists:users,id|distinct",
            "users.*.rank" => "required_with:users|numeric|integer",
        ];
    }
}
