<?php

namespace Tests\Feature;

use App\Models\Server;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Foundation\Testing\WithFaker;
use Tests\TestCase;

use App\Models\User;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Auth;

class ServerLogoutTest extends TestCase
{
    use RefreshDatabase;
    
    public function test_no_auth()
    {
        $response = $this->post('/api/auth/server/logout');
        $response->assertStatus(401);
    }
    
    public function test_wrong_token()
    {
        $response = $this->withHeaders([
            "Authorization" => "Bearer randombearer"
        ])->post('/api/auth/server/logout');
        $response->assertStatus(401);
    }
    
    public function test_good()
    {
        $user = User::create([
            'username' => 'test',
            'email' => 'test@localhost',
            'password' => Hash::make('test'),
        ]);

        $server = Server::create([
            'login' => 'test',
            'password' => Hash::make('test'),
            'owner_id' => $user->id,
        ]);
        $token = Auth::login($server);

        $response = $this->withHeaders([
            "Authorization" => "Bearer " . $token
        ])->post('/api/auth/server/logout');
        $response->assertStatus(204);
    }
}
